# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin
from django.contrib.auth.hashers import make_password

from api.wx_views import get_course_field_limit_scene_qrcode_url
from registration.models import (BranchCampusAdministratorInfo, BranchCampusInfo, CourseInfo, CourseRegisterFieldInfo,
                                 CourseRegisterFieldPoolInfo, CourseRegisterInfo, UserCourseRegisterInfo)


class BranchCampusInfoAdmin(admin.ModelAdmin):
    list_display = ('campus_id', 'campus_name', 'updated_at', 'created_at')


class BranchCampusAdministratorInfoAdmin(admin.ModelAdmin):
    list_display = ('admin_id', 'campus_id', 'campus_name', 'name', 'phone', 'password', 'encryption', 'user_status', 'updated_at', 'created_at')

    def save_model(self, request, obj, form, change):
        password = obj.password or obj.phone[-6:]
        obj.encryption = make_password(password, settings.MAKE_PASSWORD_SALT, settings.MAKE_PASSWORD_HASHER)
        obj.save()


class CourseInfoAdmin(admin.ModelAdmin):
    list_display = ('course_id', 'course_name', 'updated_at', 'created_at')


class CourseRegisterFieldPoolInfoAdmin(admin.ModelAdmin):
    list_display = ('field_type', 'field_name', 'field_options', 'updated_at', 'created_at')


class CourseRegisterFieldInfoAdmin(admin.ModelAdmin):
    list_display = ('field_id', 'course_id', 'course_name', 'fields', 'limit_scene_qrcode_url', 'updated_at', 'created_at')

    def save_model(self, request, obj, form, change):
        obj.save()

        if obj.limit_scene_qrcode_url:
            return

        obj.limit_scene_qrcode_url = get_course_field_limit_scene_qrcode_url(obj.field_id)
        obj.save()


class CourseRegisterInfoAdmin(admin.ModelAdmin):
    list_display = ('campus_id', 'campus_name', 'admin_id', 'admin_name', 'user_id', 'field_id', 'course_id', 'course_name', 'fields', 'updated_at', 'created_at')


class UserCourseRegisterInfoAdmin(admin.ModelAdmin):
    list_display = ('campus_id', 'campus_name', 'admin_id', 'admin_name', 'user_id', 'course_id', 'course_name', 'fields', 'updated_at', 'created_at')


admin.site.register(BranchCampusInfo, BranchCampusInfoAdmin)
admin.site.register(BranchCampusAdministratorInfo, BranchCampusAdministratorInfoAdmin)
admin.site.register(CourseInfo, CourseInfoAdmin)
admin.site.register(CourseRegisterFieldPoolInfo, CourseRegisterFieldPoolInfoAdmin)
admin.site.register(CourseRegisterFieldInfo, CourseRegisterFieldInfoAdmin)
admin.site.register(CourseRegisterInfo, CourseRegisterInfoAdmin)
admin.site.register(UserCourseRegisterInfo, UserCourseRegisterInfoAdmin)
